unit View.Main;

interface

uses
  System.SysUtils, System.Classes, WEBLib.Graphics, WEBLib.Forms, WEBLib.Dialogs,
  Vcl.Controls, Vcl.Forms, WEBLib.Controls, WEBLib.ExtCtrls, Vcl.StdCtrls, WEBLib.StdCtrls,
  App.Types,
  ConnectionModule, WEBLib.Lists,

  View.Crud.Container;

type
  TFViewMain = class(TWebForm)
    WebPanel1: TWebPanel;
    lbViewHome: TWebLinkLabel;  
    lbViewPortalKundeNachrichten: TWebLinkLabel;
    lbViewPortalNachrichten: TWebLinkLabel;
    lbViewPortalKunde: TWebLinkLabel;
    lbViewPortalProtokoll: TWebLinkLabel;
    lbViewPortalPfand: TWebLinkLabel;
    procedure WebFormCreate(Sender: TObject);    
	procedure lbViewHomeClick(Sender: TObject);	
    procedure lbViewPortalKundeNachrichtenClick(Sender: TObject);
    procedure lbViewPortalNachrichtenClick(Sender: TObject);
    procedure lbViewPortalKundeClick(Sender: TObject);
    procedure lbViewPortalProtokollClick(Sender: TObject);
    procedure lbViewPortalPfandClick(Sender: TObject);
  private
    FChildForm: TWebForm;
    procedure ShowForm(AFormClass: TWebFormClass);
    procedure ShowCrudContainer(ACrudFormClass: TWebFormClass; ATitle: string;
      AShowCrudListProc: TShowCrudListProc; AShowCrudEditProc: TShowCrudEditProc);
  public
    class procedure Display(AElementId: string; LogoutProc: TLogoutProc);
  end;

var
  FViewMain: TFViewMain;

implementation

uses
  JS, Web,
  Auth.Service,
  View.Login,
  View.UserProfile,  
  View.PortalKundeNachrichten.List,
  View.PortalKundeNachrichten.Edit,
  View.PortalNachrichten.List,
  View.PortalNachrichten.Edit,
  View.PortalKunde.List,
  View.PortalKunde.Edit,
  View.PortalProtokoll.List,
  View.PortalProtokoll.Edit,
  View.PortalPfand.List,
  View.PortalPfand.Edit,
  View.Home;

{$R *.dfm}

procedure TFViewMain.WebFormCreate(Sender: TObject);
begin
  FChildForm := nil;
  ShowForm(TFViewHome);
end;

procedure TFViewMain.lbViewHomeClick(Sender: TObject);
begin
  ShowForm(TFViewHome);
end;

procedure TFViewMain.lbViewPortalKundeNachrichtenClick(Sender: TObject);

  function CreatePortalKundeNachrichtenListForm(const AElementId: string; AEditProc: TEditProc): TWebForm;
  begin
    Result := TFViewPortalKundeNachrichtenList.CreateForm(AElementId, AEditProc);
  end;

  function CreatePortalKundeNachrichtenEditForm(const AElementId: string; AListProc: TListProc;
    AId: JSValue): TWebForm;
  begin
    Result := TFViewPortalKundeNachrichtenEdit.CreateForm(AElementId, AListProc, AId);
  end;

begin
  ShowCrudContainer(TFViewPortalKundeNachrichtenList, 'PortalKundeNachrichten', @CreatePortalKundeNachrichtenListForm, @CreatePortalKundeNachrichtenEditForm);
end;

procedure TFViewMain.lbViewPortalNachrichtenClick(Sender: TObject);

  function CreatePortalNachrichtenListForm(const AElementId: string; AEditProc: TEditProc): TWebForm;
  begin
    Result := TFViewPortalNachrichtenList.CreateForm(AElementId, AEditProc);
  end;

  function CreatePortalNachrichtenEditForm(const AElementId: string; AListProc: TListProc;
    AId: JSValue): TWebForm;
  begin
    Result := TFViewPortalNachrichtenEdit.CreateForm(AElementId, AListProc, AId);
  end;

begin
  ShowCrudContainer(TFViewPortalNachrichtenList, 'PortalNachrichten', @CreatePortalNachrichtenListForm, @CreatePortalNachrichtenEditForm);
end;

procedure TFViewMain.lbViewPortalKundeClick(Sender: TObject);

  function CreatePortalKundeListForm(const AElementId: string; AEditProc: TEditProc): TWebForm;
  begin
    Result := TFViewPortalKundeList.CreateForm(AElementId, AEditProc);
  end;

  function CreatePortalKundeEditForm(const AElementId: string; AListProc: TListProc;
    AId: JSValue): TWebForm;
  begin
    Result := TFViewPortalKundeEdit.CreateForm(AElementId, AListProc, AId);
  end;

begin
  ShowCrudContainer(TFViewPortalKundeList, 'PortalKunde', @CreatePortalKundeListForm, @CreatePortalKundeEditForm);
end;

procedure TFViewMain.lbViewPortalProtokollClick(Sender: TObject);

  function CreatePortalProtokollListForm(const AElementId: string; AEditProc: TEditProc): TWebForm;
  begin
    Result := TFViewPortalProtokollList.CreateForm(AElementId, AEditProc);
  end;

  function CreatePortalProtokollEditForm(const AElementId: string; AListProc: TListProc;
    AId: JSValue): TWebForm;
  begin
    Result := TFViewPortalProtokollEdit.CreateForm(AElementId, AListProc, AId);
  end;

begin
  ShowCrudContainer(TFViewPortalProtokollList, 'PortalProtokoll', @CreatePortalProtokollListForm, @CreatePortalProtokollEditForm);
end;

procedure TFViewMain.lbViewPortalPfandClick(Sender: TObject);

  function CreatePortalPfandListForm(const AElementId: string; AEditProc: TEditProc): TWebForm;
  begin
    Result := TFViewPortalPfandList.CreateForm(AElementId, AEditProc);
  end;

  function CreatePortalPfandEditForm(const AElementId: string; AListProc: TListProc;
    AId: JSValue): TWebForm;
  begin
    Result := TFViewPortalPfandEdit.CreateForm(AElementId, AListProc, AId);
  end;

begin
  ShowCrudContainer(TFViewPortalPfandList, 'PortalPfand', @CreatePortalPfandListForm, @CreatePortalPfandEditForm);
end;



class procedure TFViewMain.Display(AElementId: string; LogoutProc: TLogoutProc);

  procedure AfterCreate(AForm: TObject);
  begin
    //TFViewMain(AForm).FLogoutProc := LogoutProc;
  end;

begin
  if Assigned(FViewMain) then
    FViewMain.Free;
  FViewMain := TFViewMain.CreateNew(AElementId, @AfterCreate);
end;

procedure TFViewMain.ShowCrudContainer(ACrudFormClass: TWebFormClass; ATitle: string;
  AShowCrudListProc: TShowCrudListProc; AShowCrudEditProc: TShowCrudEditProc);

  function CreateAlbumListForm(const AElementId: string; AEditProc: TEditProc): TWebForm;
    procedure AfterCreateListForm(Form: TObject);
    begin
      TJSObject(Form)['FEditProc'] := AEditProc;
    end;
  begin
    Application.CreateForm(ACrudFormClass, AElementId, Result, @AfterCreateListForm);
  end;

  function CreateAlbumEditForm(const AElementId: string; AListProc: TListProc;
    AId: JSValue): TWebForm;
    procedure AfterCreateEditForm(Form: TObject);
    begin
      //TJSObject(Form)['FEditProc'] := AEditProc;
    end;
  begin
    //Application.CreateForm(ACrudFormClass, AElementId, Result, @AfterCreateListForm);

    //Result := TFViewAlbumEdit.CreateForm(AElementId, AListProc, AId);
  end;

begin
  if Assigned(FChildForm) then
    FChildForm.Free;
  FChildForm := TFViewCrudContainer.CreateForm(WebPanel1.ElementID,
    ATitle, @CreateAlbumListForm, AShowCrudEditProc
  );
end;

procedure TFViewMain.ShowForm(AFormClass: TWebFormClass);
begin
  if Assigned(FChildForm) then
    FChildForm.Free;
  Application.CreateForm(AFormClass, WebPanel1.ElementID, FChildForm);
end;

end.
